==> mongodb-7.0.18.gh.tar.gz: mongo-r7.0.18/src/mongo/client/replica_set_monitor_protocol_test_util.cpp <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */
#include "mongo/platform/basic.h"

#include "mongo/client/replica_set_monitor_protocol_test_util.h"
#include "mongo/util/assert_util.h"

namespace mongo {
void ReplicaSetMonitorProtocolTestUtil::setRSMProtocol(ReplicaSetMonitorProtocol protocol) {
    const BSONObj newParameterObj = BSON(kRSMProtocolFieldName << toString(protocol));
    BSONObjIterator parameterIterator(newParameterObj);
    BSONElement newParameter = parameterIterator.next();
    const auto foundParameter = findRSMProtocolServerParameter();

    uassertStatusOK(foundParameter->second->set(newParameter, boost::none));
}

void ReplicaSetMonitorProtocolTestUtil::resetRSMProtocol() {
    const auto defaultParameter = kDefaultParameter[kRSMProtocolFieldName];
    const auto foundParameter = findRSMProtocolServerParameter();

    uassertStatusOK(foundParameter->second->set(defaultParameter, boost::none));
}

ServerParameter::Map::const_iterator
ReplicaSetMonitorProtocolTestUtil::findRSMProtocolServerParameter() {
    const auto& parameterMap = ServerParameterSet::getNodeParameterSet()->getMap();
    invariant(parameterMap.size());
    return parameterMap.find(kRSMProtocolFieldName);
}

}  // namespace mongo

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/client/replica_set_monitor_protocol_test_util.cpp <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */
#include <map>
#include <utility>

#include <boost/move/utility_core.hpp>
#include <boost/none.hpp>

#include "mongo/bson/bsonelement.h"
#include "mongo/client/replica_set_monitor_protocol_test_util.h"
#include "mongo/db/tenant_id.h"
#include "mongo/util/assert_util.h"

namespace mongo {
void ReplicaSetMonitorProtocolTestUtil::setRSMProtocol(ReplicaSetMonitorProtocol protocol) {
    const BSONObj newParameterObj = BSON(kRSMProtocolFieldName << toString(protocol));
    BSONObjIterator parameterIterator(newParameterObj);
    BSONElement newParameter = parameterIterator.next();
    const auto foundParameter = findRSMProtocolServerParameter();

    uassertStatusOK(foundParameter->second->set(newParameter, boost::none));
}

void ReplicaSetMonitorProtocolTestUtil::resetRSMProtocol() {
    const auto defaultParameter = kDefaultParameter[kRSMProtocolFieldName];
    const auto foundParameter = findRSMProtocolServerParameter();

    uassertStatusOK(foundParameter->second->set(defaultParameter, boost::none));
}

ServerParameter::Map::const_iterator
ReplicaSetMonitorProtocolTestUtil::findRSMProtocolServerParameter() {
    const auto& parameterMap = ServerParameterSet::getNodeParameterSet()->getMap();
    invariant(parameterMap.size());
    return parameterMap.find(kRSMProtocolFieldName);
}

}  // namespace mongo
